@@ -16,7 +16,18 @@
 from collections import OrderedDict
 import os
 import re
-from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
+from typing import (
+    Dict,
+    Mapping,
+    MutableMapping,
+    MutableSequence,
+    Optional,
+    Sequence,
+    Tuple,
+    Type,
+    Union,
+    cast,
+)
 
 from google.api_core import client_options as client_options_lib
 from google.api_core import exceptions as core_exceptions
@@ -27,7 +38,8 @@ from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
-import pkg_resources
+
+from google.cloud.gaming_v1 import gapic_version as package_version
 
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
@@ -66,7 +78,7 @@ class GameServerDeploymentsServiceClientMeta(type):
 
     def get_transport_class(
         cls,
-        label: str = None,
+        label: Optional[str] = None,
     ) -> Type[GameServerDeploymentsServiceTransport]:
         """Returns an appropriate transport class.
 
@@ -367,8 +379,8 @@ class GameServerDeploymentsServiceClient(
         self,
         *,
         credentials: Optional[ga_credentials.Credentials] = None,
-        transport: Union[str, GameServerDeploymentsServiceTransport, None] = None,
-        client_options: Optional[client_options_lib.ClientOptions] = None,
+        transport: Optional[Union[str, GameServerDeploymentsServiceTransport]] = None,
+        client_options: Optional[Union[client_options_lib.ClientOptions, dict]] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
         """Instantiates the game server deployments service client.
@@ -382,7 +394,7 @@ class GameServerDeploymentsServiceClient(
             transport (Union[str, GameServerDeploymentsServiceTransport]): The
                 transport to use. If set to None, a transport is chosen
                 automatically.
-            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+            client_options (Optional[Union[google.api_core.client_options.ClientOptions, dict]]): Custom options for the
                 client. It won't take effect if a ``transport`` instance is provided.
                 (1) The ``api_endpoint`` property can be used to override the
                 default endpoint provided by the client. GOOGLE_API_USE_MTLS_ENDPOINT
@@ -412,6 +424,7 @@ class GameServerDeploymentsServiceClient(
             client_options = client_options_lib.from_dict(client_options)
         if client_options is None:
             client_options = client_options_lib.ClientOptions()
+        client_options = cast(client_options_lib.ClientOptions, client_options)
 
         api_endpoint, client_cert_source_func = self.get_mtls_endpoint_and_cert_source(
             client_options
@@ -464,13 +477,13 @@ class GameServerDeploymentsServiceClient(
 
     def list_game_server_deployments(
         self,
-        request: Union[
-            game_server_deployments.ListGameServerDeploymentsRequest, dict
+        request: Optional[
+            Union[game_server_deployments.ListGameServerDeploymentsRequest, dict]
         ] = None,
         *,
-        parent: str = None,
+        parent: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListGameServerDeploymentsPager:
         r"""Lists game server deployments in a given project and
@@ -586,13 +599,13 @@ class GameServerDeploymentsServiceClient(
 
     def get_game_server_deployment(
         self,
-        request: Union[
-            game_server_deployments.GetGameServerDeploymentRequest, dict
+        request: Optional[
+            Union[game_server_deployments.GetGameServerDeploymentRequest, dict]
         ] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> game_server_deployments.GameServerDeployment:
         r"""Gets details of a single game server deployment.
@@ -693,14 +706,16 @@ class GameServerDeploymentsServiceClient(
 
     def create_game_server_deployment(
         self,
-        request: Union[
-            game_server_deployments.CreateGameServerDeploymentRequest, dict
+        request: Optional[
+            Union[game_server_deployments.CreateGameServerDeploymentRequest, dict]
         ] = None,
         *,
-        parent: str = None,
-        game_server_deployment: game_server_deployments.GameServerDeployment = None,
+        parent: Optional[str] = None,
+        game_server_deployment: Optional[
+            game_server_deployments.GameServerDeployment
+        ] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation.Operation:
         r"""Creates a new game server deployment in a given
@@ -828,13 +843,13 @@ class GameServerDeploymentsServiceClient(
 
     def delete_game_server_deployment(
         self,
-        request: Union[
-            game_server_deployments.DeleteGameServerDeploymentRequest, dict
+        request: Optional[
+            Union[game_server_deployments.DeleteGameServerDeploymentRequest, dict]
         ] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation.Operation:
         r"""Deletes a single game server deployment.
@@ -959,14 +974,16 @@ class GameServerDeploymentsServiceClient(
 
     def update_game_server_deployment(
         self,
-        request: Union[
-            game_server_deployments.UpdateGameServerDeploymentRequest, dict
+        request: Optional[
+            Union[game_server_deployments.UpdateGameServerDeploymentRequest, dict]
         ] = None,
         *,
-        game_server_deployment: game_server_deployments.GameServerDeployment = None,
-        update_mask: field_mask_pb2.FieldMask = None,
+        game_server_deployment: Optional[
+            game_server_deployments.GameServerDeployment
+        ] = None,
+        update_mask: Optional[field_mask_pb2.FieldMask] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation.Operation:
         r"""Patches a game server deployment.
@@ -1096,13 +1113,13 @@ class GameServerDeploymentsServiceClient(
 
     def get_game_server_deployment_rollout(
         self,
-        request: Union[
-            game_server_deployments.GetGameServerDeploymentRolloutRequest, dict
+        request: Optional[
+            Union[game_server_deployments.GetGameServerDeploymentRolloutRequest, dict]
         ] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> game_server_deployments.GameServerDeploymentRollout:
         r"""Gets details a single game server deployment rollout.
@@ -1208,14 +1225,16 @@ class GameServerDeploymentsServiceClient(
 
     def update_game_server_deployment_rollout(
         self,
-        request: Union[
-            game_server_deployments.UpdateGameServerDeploymentRolloutRequest, dict
+        request: Optional[
+            Union[
+                game_server_deployments.UpdateGameServerDeploymentRolloutRequest, dict
+            ]
         ] = None,
         *,
-        rollout: game_server_deployments.GameServerDeploymentRollout = None,
-        update_mask: field_mask_pb2.FieldMask = None,
+        rollout: Optional[game_server_deployments.GameServerDeploymentRollout] = None,
+        update_mask: Optional[field_mask_pb2.FieldMask] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation.Operation:
         r"""Patches a single game server deployment rollout. The method will
@@ -1353,12 +1372,14 @@ class GameServerDeploymentsServiceClient(
 
     def preview_game_server_deployment_rollout(
         self,
-        request: Union[
-            game_server_deployments.PreviewGameServerDeploymentRolloutRequest, dict
+        request: Optional[
+            Union[
+                game_server_deployments.PreviewGameServerDeploymentRolloutRequest, dict
+            ]
         ] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> game_server_deployments.PreviewGameServerDeploymentRolloutResponse:
         r"""Previews the game server deployment rollout. This API
@@ -1446,12 +1467,12 @@ class GameServerDeploymentsServiceClient(
 
     def fetch_deployment_state(
         self,
-        request: Union[
-            game_server_deployments.FetchDeploymentStateRequest, dict
+        request: Optional[
+            Union[game_server_deployments.FetchDeploymentStateRequest, dict]
         ] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> game_server_deployments.FetchDeploymentStateResponse:
         r"""Retrieves information about the current state of the
@@ -1544,14 +1565,9 @@ class GameServerDeploymentsServiceClient(
         self.transport.close()
 
 
-try:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution(
-            "google-cloud-game-servers",
-        ).version,
-    )
-except pkg_resources.DistributionNotFound:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
+DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
+    gapic_version=package_version.__version__
+)
 
 
 __all__ = ("GameServerDeploymentsServiceClient",)
