@@ -1,6 +1,5 @@
 # -*- coding: utf-8 -*-
-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -16,7 +15,10 @@
 #
 
 
-__protobuf__ = proto.module(package="google.cloud.gaming.v1beta", manifest={},)
+__protobuf__ = proto.module(
+    package="google.cloud.gaming.v1",
+    manifest={},
+)
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
