@@ -16,7 +16,18 @@
 from collections import OrderedDict
 import os
 import re
-from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
+from typing import (
+    Dict,
+    Mapping,
+    MutableMapping,
+    MutableSequence,
+    Optional,
+    Sequence,
+    Tuple,
+    Type,
+    Union,
+    cast,
+)
 
 from google.api_core import client_options as client_options_lib
 from google.api_core import exceptions as core_exceptions
@@ -27,7 +38,8 @@ from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
-import pkg_resources
+
+from google.cloud.gaming_v1beta import gapic_version as package_version
 
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
@@ -62,7 +74,7 @@ class RealmsServiceClientMeta(type):
 
     def get_transport_class(
         cls,
-        label: str = None,
+        label: Optional[str] = None,
     ) -> Type[RealmsServiceTransport]:
         """Returns an appropriate transport class.
 
@@ -339,8 +351,8 @@ class RealmsServiceClient(metaclass=RealmsServiceClientMeta):
         self,
         *,
         credentials: Optional[ga_credentials.Credentials] = None,
-        transport: Union[str, RealmsServiceTransport, None] = None,
-        client_options: Optional[client_options_lib.ClientOptions] = None,
+        transport: Optional[Union[str, RealmsServiceTransport]] = None,
+        client_options: Optional[Union[client_options_lib.ClientOptions, dict]] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
         """Instantiates the realms service client.
@@ -354,7 +366,7 @@ class RealmsServiceClient(metaclass=RealmsServiceClientMeta):
             transport (Union[str, RealmsServiceTransport]): The
                 transport to use. If set to None, a transport is chosen
                 automatically.
-            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+            client_options (Optional[Union[google.api_core.client_options.ClientOptions, dict]]): Custom options for the
                 client. It won't take effect if a ``transport`` instance is provided.
                 (1) The ``api_endpoint`` property can be used to override the
                 default endpoint provided by the client. GOOGLE_API_USE_MTLS_ENDPOINT
@@ -384,6 +396,7 @@ class RealmsServiceClient(metaclass=RealmsServiceClientMeta):
             client_options = client_options_lib.from_dict(client_options)
         if client_options is None:
             client_options = client_options_lib.ClientOptions()
+        client_options = cast(client_options_lib.ClientOptions, client_options)
 
         api_endpoint, client_cert_source_func = self.get_mtls_endpoint_and_cert_source(
             client_options
@@ -436,11 +449,11 @@ class RealmsServiceClient(metaclass=RealmsServiceClientMeta):
 
     def list_realms(
         self,
-        request: Union[realms.ListRealmsRequest, dict] = None,
+        request: Optional[Union[realms.ListRealmsRequest, dict]] = None,
         *,
-        parent: str = None,
+        parent: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListRealmsPager:
         r"""Lists realms in a given project and location.
@@ -551,11 +564,11 @@ class RealmsServiceClient(metaclass=RealmsServiceClientMeta):
 
     def get_realm(
         self,
-        request: Union[realms.GetRealmRequest, dict] = None,
+        request: Optional[Union[realms.GetRealmRequest, dict]] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> realms.Realm:
         r"""Gets details of a single realm.
@@ -652,13 +665,13 @@ class RealmsServiceClient(metaclass=RealmsServiceClientMeta):
 
     def create_realm(
         self,
-        request: Union[realms.CreateRealmRequest, dict] = None,
+        request: Optional[Union[realms.CreateRealmRequest, dict]] = None,
         *,
-        parent: str = None,
-        realm: realms.Realm = None,
-        realm_id: str = None,
+        parent: Optional[str] = None,
+        realm: Optional[realms.Realm] = None,
+        realm_id: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation.Operation:
         r"""Creates a new realm in a given project and location.
@@ -794,11 +807,11 @@ class RealmsServiceClient(metaclass=RealmsServiceClientMeta):
 
     def delete_realm(
         self,
-        request: Union[realms.DeleteRealmRequest, dict] = None,
+        request: Optional[Union[realms.DeleteRealmRequest, dict]] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation.Operation:
         r"""Deletes a single realm.
@@ -919,12 +932,12 @@ class RealmsServiceClient(metaclass=RealmsServiceClientMeta):
 
     def update_realm(
         self,
-        request: Union[realms.UpdateRealmRequest, dict] = None,
+        request: Optional[Union[realms.UpdateRealmRequest, dict]] = None,
         *,
-        realm: realms.Realm = None,
-        update_mask: field_mask_pb2.FieldMask = None,
+        realm: Optional[realms.Realm] = None,
+        update_mask: Optional[field_mask_pb2.FieldMask] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation.Operation:
         r"""Patches a single realm.
@@ -1054,10 +1067,10 @@ class RealmsServiceClient(metaclass=RealmsServiceClientMeta):
 
     def preview_realm_update(
         self,
-        request: Union[realms.PreviewRealmUpdateRequest, dict] = None,
+        request: Optional[Union[realms.PreviewRealmUpdateRequest, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> realms.PreviewRealmUpdateResponse:
         r"""Previews patches to a single realm.
@@ -1152,14 +1165,9 @@ class RealmsServiceClient(metaclass=RealmsServiceClientMeta):
         self.transport.close()
 
 
-try:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution(
-            "google-cloud-game-servers",
-        ).version,
-    )
-except pkg_resources.DistributionNotFound:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
+DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
+    gapic_version=package_version.__version__
+)
 
 
 __all__ = ("RealmsServiceClient",)
